==> haskell-colour-2.3.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.5
id: colour-2.3.5-LxSXSQgiXBSD7UDNovuSa8
key: colour-2.3.5-LxSXSQgiXBSD7UDNovuSa8
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
author: Russell O'\''Connor
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
abi: 21c092d68d574bce8e2b72f6b38d1465
exposed: True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
import-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.5-LxSXSQgiXBSD7UDNovuSa8
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.5
id: colour-2.3.5-IwrhnRlkf9iITzt389YBqc
key: colour-2.3.5-IwrhnRlkf9iITzt389YBqc
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
author: Russell O'\''Connor
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
abi: 611301ee46a22ccd81f4f1db329af1cd
exposed: True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
import-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.5-IwrhnRlkf9iITzt389YBqc
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
